package App::Charon;
$App::Charon::VERSION = '0.001001';
# ABSTRACT: See charon

__END__

=pod

=encoding UTF-8

=head1 NAME

App::Charon - See charon

=head1 VERSION

version 0.001001

=head1 STUB

I have to have this because reasons.  See the real doc at L<charon>.

1;

=head1 AUTHOR

Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
